@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
-from webob import Request, Response
-from pyquery import PyQuery as Base
-from pyquery import no_default
+import sys
+from .pyquery import PyQuery as Base
+from .pyquery import no_default
+
+if sys.version_info < (3,):
+    from webob import Request, Response
 
 try:
     from paste.proxy import Proxy
